@@ -83,7 +83,8 @@ if __name__ == "__main__":
         swimmer_file = "swimmer.xlsx"
         swimmer_data = pd.read_excel(str(data_path.path) + "/" + swimmer_file)
         swimmer_data = swimmer_data.iloc[:, 2:]
-        # swimmer_screeplot = nmf.generate_scree_plot(swimmer_data, ncmin=2, ncmax=30)
+        swimmer_screeplot = nmf.generate_scree_plot(swimmer_data, ncmin=2, ncmax=30)
+        swimmer_screeplot.to_csv(str(res_path) + "/swimmer_screeplots.csv")
         recalc_swimmer = False
         ncmin = 2
         ncmax = 30
@@ -106,7 +107,7 @@ if __name__ == "__main__":
         sausage_data = pd.read_excel(str(data_path.path) + "/" + sausage_file)
         sausage_data = sausage_data.iloc[:, 1:]
         # sausage_screeplot = nmf.generate_scree_plot(sausage_data, ncmin=2, ncmax=30)
-        recalc_sausage = True
+        recalc_sausage = False
         ncmin = 2
         ncmax = 20
         if recalc_sausage:
